@@ -1,11 +1,7 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import
-# Copyright (c) 2010-2019 openpyxl
-
+# Copyright (c) 2010-2021 openpyxl
 
 """Write the theme xml based on a fixed string."""
 
-# package imports
 
 theme_xml = """<?xml version="1.0"?>
 <a:theme xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main" name="Office Theme">
